==> kafka-3.7.2-src.tgz: kafka-3.7.2-src/streams/src/test/java/org/apache/kafka/streams/processor/FailOnInvalidTimestampTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.kafka.streams.processor;

import org.apache.kafka.clients.consumer.ConsumerRecord;
import org.apache.kafka.streams.errors.StreamsException;
import static org.junit.Assert.assertThrows;
import org.junit.Test;

public class FailOnInvalidTimestampTest extends TimestampExtractorTest {

    @Test
    public void extractMetadataTimestamp() {
        testExtractMetadataTimestamp(new FailOnInvalidTimestamp());
    }

    @Test
    public void failOnInvalidTimestamp() {
        final TimestampExtractor extractor = new FailOnInvalidTimestamp();
        assertThrows(StreamsException.class, () -> extractor.extract(new ConsumerRecord<>("anyTopic",
                0, 0, null, null), 42));
    }

}

==> kafka-3.8.0-src.tgz: kafka-3.8.0-src/streams/src/test/java/org/apache/kafka/streams/processor/FailOnInvalidTimestampTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.kafka.streams.processor;

import org.apache.kafka.clients.consumer.ConsumerRecord;
import org.apache.kafka.streams.errors.StreamsException;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertThrows;

public class FailOnInvalidTimestampTest extends TimestampExtractorTest {

    @Test
    public void extractMetadataTimestamp() {
        testExtractMetadataTimestamp(new FailOnInvalidTimestamp());
    }

    @Test
    public void failOnInvalidTimestamp() {
        final TimestampExtractor extractor = new FailOnInvalidTimestamp();
        assertThrows(StreamsException.class, () -> extractor.extract(new ConsumerRecord<>("anyTopic",
                0, 0, null, null), 42));
    }
}
